@@ -1,7 +1,7 @@
 #' Pressure Derivative with Respect to Temperature, Function of Temperature and Density
 #'
-#' @description The function \code{dpdTTD(T,D)} returns the pressure derivative with 
-#'     respect to Temperature, dpdT, for given T [K] and D [kg/m3].
+#' @description The function \code{dpdTTD(Temp,D,digits=9)} returns the pressure derivative with 
+#'     respect to Temperature, dpdT, for given Temp [K] and D [kg/m3].
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
 #'     in accordance with the Revised Release on the IAPWS Formulation 1995 for the 
@@ -10,36 +10,36 @@
 #'     Water and Steam,  \url{http://www.iapws.org/relguide/IAPWS-95.html}. It is valid  
 #'     from the triple point to the pressure of 1000 MPa and temperature of 1273.
 #'     
-#' @param T Temperature [ K ]
+#' @param Temp Temperature [ K ]
 #' @param D Density [ kg m-3 ]
+#' @param digits Digits of results (optional)
 #' 
-#' @return The pressure derivative with respect to T: dp/dT [ MPa K-1 ] and an Error
+#' @return The pressure derivative with respect to Temp: dp/dTemp [ MPa K-1 ] and an Error
 #'      Message (if an error occur: \link{errorCodes})
 #' 
 #' @examples
-#' T <- 500.
+#' Temp <- 500.
 #' D <- 838.025
-#' dpdT <- dpdTTD(T,D)
-#' dpdT
+#' dpdTemp <- dpdTTD(Temp,D)
+#' dpdTemp
 #' 
 #' @export
 #' 
-  dpdTTD <- function(T,D) {
+  dpdTTD <- function(Temp,D,digits=9) {
   y <- 0.
   icode <- 0
-  res <- .Fortran('dpdTTD', as.double(T), as.double(D), as.double(y), as.integer(icode))
-  options(digits=9)
+  res <- .Fortran('dpdTTD', as.double(Temp), as.double(D), as.double(y), as.integer(icode))
   if (res[[4]] != 0) { 
      error <-  as.character(errorCodes[which(errorCodes[,1]==res[[4]]),2])
      print(error)
   }
-  return(res[[3]])
+  return(round(res[[3]],digits=digits))
   }
 
 #' Pressure Derivative with respect to Temperature, Function of Temperature and Pressure
 #'
-#' @description The function \code{dpdTTp(T,p)} returns the pressure derivative with 
-#'     respect to Temperature, dpdT, for given T [K] and p [MPa].
+#' @description The function \code{dpdTTp(Temp,p,digits=9)} returns the pressure derivative with 
+#'     respect to Temperature, dpdTemp, for given Temp [K] and p [MPa].
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
 #'     in accordance with the Revised Release on the IAPWS Formulation 1995 for the 
@@ -48,35 +48,35 @@
 #'     Water and Steam,  \url{http://www.iapws.org/relguide/IAPWS-95.html}. It is valid  
 #'     from the triple point to the pressure of 1000 MPa and temperature of 1273.
 #'     
-#' @param T Temperature [ K ]
+#' @param Temp Temperature [ K ]
 #' @param p Pressure [ MPa ]
+#' @param digits Digits of results (optional)
 #' 
-#' @return The pressure derivative with respect to T: dp/dT [ MPa K-1 ] and an Error
+#' @return The pressure derivative with respect to Temp: dp/dTemp [ MPa K-1 ] and an Error
 #'      Message (if an error occur: \link{errorCodes})
 #' 
 #' @examples
-#' T <- 500.
+#' Temp <- 500.
 #' p <- 10.0003858
-#' dpdT <- dpdTTp(T,p)
-#' dpdT
+#' dpdTemp <- dpdTTp(Temp,p)
+#' dpdTemp
 #' 
 #' @export
 #' 
-  dpdTTp <- function(T,p) {
+  dpdTTp <- function(Temp,p,digits=9) {
     y <- 0.
     icode <- 0
-    res <- .Fortran('dpdTTp', as.double(T), as.double(p), as.double(y), as.integer(icode))
-    options(digits=9)
+    res <- .Fortran('dpdTTp', as.double(Temp), as.double(p), as.double(y), as.integer(icode))
     if (res[[4]] != 0) { 
       error <-  as.character(errorCodes[which(errorCodes[,1]==res[[4]]),2])
       print(error)
     }
-    return(res[[3]])
+    return(round(res[[3]],digits=digits))
   }
   
 #' Pressure Derivative with respect to Density, Function of Temperature and Density
 #'
-#' @description The function \code{dpdDTD(T,D)} returns the pressure derivative with 
+#' @description The function \code{dpdDTD(Temp,D,digits=9)} returns the pressure derivative with 
 #'     respect to Density, dpdD, for given T [K] and D [kg m-3].
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
@@ -86,36 +86,35 @@
 #'     Water and Steam,  \url{http://www.iapws.org/relguide/IAPWS-95.html}. It is valid  
 #'     from the triple point to the pressure of 1000 MPa and temperature of 1273.
 #'     
-#' @param T Temperature [ K ]
+#' @param Temp Temperature [ K ]
 #' @param D Density [ kg m-3 ]
-#' 
+#' @param digits Digits of results (optional)
 #' @return The pressure derivative with respect to D: dp/dD [ MPa kg-1 m3  ] and an Error
 #'      Message (if an error occur: \link{errorCodes})
 #' 
 #' @examples
-#' T <- 500.
+#' Temp <- 500.
 #' D <- 838.025
-#' dpdD <- dpdDTD(T,D)
+#' dpdD <- dpdDTD(Temp,D)
 #' dpdD
 #' 
 #' @export
 #' 
-   dpdDTD <- function(T,D) {
+   dpdDTD <- function(Temp,D,digits=9) {
     y <- 0.
     icode <- 0
-    res <- .Fortran('dpdDTD', as.double(T), as.double(D), as.double(y), as.integer(icode))
-    options(digits=9)
+    res <- .Fortran('dpdDTD', as.double(Temp), as.double(D), as.double(y), as.integer(icode))
     if (res[[4]] != 0) { 
       error <-  as.character(errorCodes[which(errorCodes[,1]==res[[4]]),2])
       print(error)
     }
-    return(res[[3]])
+    return(round(res[[3]],digits=digits))
   }
   
 #' Pressure Derivative with respect to Density, Function of Temperature and Pressure
 #'
-#' @description The function \code{dpdDTp(T,p)} returns the pressure derivative with 
-#'     respect to Density, dpdD, for given T [K] and p [MPa].
+#' @description The function \code{dpdDTp(Temp,p)} returns the pressure derivative with 
+#'     respect to Density, dpdD, for given Temp [K] and p [MPa].
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
 #'     in accordance with the Revised Release on the IAPWS Formulation 1995 for the 
@@ -124,36 +123,36 @@
 #'     Water and Steam,  \url{http://www.iapws.org/relguide/IAPWS-95.html}. It is valid  
 #'     from the triple point to the pressure of 1000 MPa and temperature of 1273.
 #'     
-#' @param T Temperature [ K ]
+#' @param Temp Temperature [ K ]
 #' @param p Pressure [ MPa ]
+#' @param digits Digits of results (optional)
 #' 
 #' @return The pressure derivative with respect to d: dp/dD [ MPa kg-1 m3 ] and an Error
 #'      Message (if an error occur: \link{errorCodes})
 #' 
 #' @examples
-#' T <- 500.
+#' Temp <- 500.
 #' p <- 10.0003858
-#' dpdD <- dpdDTp(T,p)
+#' dpdD <- dpdDTp(Temp,p)
 #' dpdD
 #' 
 #' @export
 #' 
-   dpdDTp <- function(T,p) {
+   dpdDTp <- function(Temp,p,digits=9) {
      y <- 0.
      icode <- 0
-     res <- .Fortran('dpdDTp', as.double(T), as.double(p), as.double(y), as.integer(icode))
-     options(digits=9)
+     res <- .Fortran('dpdDTp', as.double(Temp), as.double(p), as.double(y), as.integer(icode))
      if (res[[4]] != 0) { 
        error <-  as.character(errorCodes[which(errorCodes[,1]==res[[4]]),2])
        print(error)
      }
-     return(res[[3]])
+     return(round(res[[3]],digits=digits))
    }
 
 #' Density Derivative with respect to Temperature, Function of Temperature and Density
 #'
-#' @description The function \code{dDdTTD(T,D)} returns the pressure derivative with 
-#'     respect to Density, dpdD, for given T [K] and D [kg m-3].
+#' @description The function \code{dDdTTD(Temp,D,digits=9)} returns the pressure derivative with 
+#'     respect to Density, dpdD, for given Temp [K] and D [kg m-3].
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
 #'     in accordance with the Revised Release on the IAPWS Formulation 1995 for the 
@@ -162,36 +161,36 @@
 #'     Water and Steam,  \url{http://www.iapws.org/relguide/IAPWS-95.html}. It is valid  
 #'     from the triple point to the pressure of 1000 MPa and temperature of 1273.
 #'     
-#' @param T Temperature [ K ]
+#' @param Temp Temperature [ K ]
 #' @param D Density [ kg m-3 ]
+#' @param digits Digits of results (optional)
 #' 
-#' @return The Density Derivative with respect to T: dD/dT [ kg m-3 K-1 ] and an Error
+#' @return The Density Derivative with respect to T: dD/dTemp [ kg m-3 K-1 ] and an Error
 #'      Message (if an error occur: \link{errorCodes})
 #' 
 #' @examples
-#' T <- 500.
+#' Temp <- 500.
 #' D <- 838.025
-#' dDdT <- dDdTTD(T,D)
-#' dDdT
+#' dDdTemp <- dDdTTD(Temp,D)
+#' dDdTemp
 #' 
 #' @export
 #' 
-   dDdTTD <- function(T,D) {
+   dDdTTD <- function(Temp,D,digits=9) {
      y <- 0.
      icode <- 0
-     res <- .Fortran('dDdTTD', as.double(T), as.double(D), as.double(y), as.integer(icode))
-     options(digits=9)
+     res <- .Fortran('dDdTTD', as.double(Temp), as.double(D), as.double(y), as.integer(icode))
      if (res[[4]] != 0) { 
        error <-  as.character(errorCodes[which(errorCodes[,1]==res[[4]]),2])
        print(error)
      }
-     return(res[[3]])
+     return(round(res[[3]],digits=digits))
    }
 
 #' Density Derivative with respect to Temperature, Function of Temperature and Pressure
 #'
-#' @description The function \code{dDdTTp(T,p)} returns the Density derivative with 
-#'     respect to Temperature, dDdT, for given T [K] and p [MPa].
+#' @description The function \code{dDdTTp(Temp,p,digits=9)} returns the Density derivative with 
+#'     respect to Temperature, dDdTemp, for given Temp [K] and p [MPa].
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
 #'     in accordance with the Revised Release on the IAPWS Formulation 1995 for the 
@@ -200,36 +199,36 @@
 #'     Water and Steam,  \url{http://www.iapws.org/relguide/IAPWS-95.html}. It is valid  
 #'     from the triple point to the pressure of 1000 MPa and temperature of 1273.
 #'     
-#' @param T Temperature [ K ]
+#' @param Temp Temperature [ K ]
 #' @param p Pressure [ MPa ]
+#' @param digits Digits of results (optional)
 #' 
-#' @return The Density derivative with respect to T: dD/dT [ kg m-3 K-1 ] and an Error
+#' @return The Density derivative with respect to Temp: dD/dTemp [ kg m-3 K-1 ] and an Error
 #'      Message (if an error occur: \link{errorCodes})
 #' 
 #' @examples
-#' T <- 500.
+#' Temp <- 500.
 #' p <- 10.0003858
-#' dDdT <- dDdTTp(T,p)
-#' dDdT
+#' dDdTemp <- dDdTTp(Temp,p)
+#' dDdTemp
 #' 
 #' @export
 #' 
-   dDdTTp <- function(T,p) {
+   dDdTTp <- function(Temp,p,digits=9) {
      y <- 0.
      icode <- 0
-     res <- .Fortran('dDdTTp', as.double(T), as.double(p), as.double(y), as.integer(icode))
-     options(digits=9)
+     res <- .Fortran('dDdTTp', as.double(Temp), as.double(p), as.double(y), as.integer(icode))
      if (res[[4]] != 0) { 
        error <-  as.character(errorCodes[which(errorCodes[,1]==res[[4]]),2])
        print(error)
      }
-     return(res[[3]])
+     return(round(res[[3]],digits=digits))
    }
 
-#' Isothermal Throttling Coefficient, Function of Tenoerature and Density
+#' Isothermal Throttling Coefficient, Function of Temperature and Density
 #'
-#' @description The function \code{ThrcTD(T,D)} returns the Isothermal Throttling Coefficient, 
-#'     Thrc, for given T [K] and D [kg m-3].
+#' @description The function \code{ThrcTD(Temp,D,digits=9)} returns the Isothermal Throttling Coefficient, 
+#'     Thrc, for given Temp [K] and D [kg m-3].
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
 #'     in accordance with the Revised Release on the IAPWS Formulation 1995 for the 
@@ -238,36 +237,36 @@
 #'     Water and Steam,  \url{http://www.iapws.org/relguide/IAPWS-95.html}. It is valid  
 #'     from the triple point to the pressure of 1000 MPa and temperature of 1273.
 #'     
-#' @param T Temperature [ K ]
+#' @param Temp Temperature [ K ]
 #' @param D Density [ kg m-3 ]
+#' @param digits Digits of results (optional)
 #' 
 #' @return The Isothermal Throttling Coefficient: Thrc [ kJ kg-1 MPa-1 ] and an Error
 #'      Message (if an error occur: \link{errorCodes})
 #' 
 #' @examples
-#' T <- 500.
+#' Temp <- 500.
 #' D <- 838.025
-#' Thrc <- ThrcTD(T,D)
+#' Thrc <- ThrcTD(Temp,D)
 #' Thrc
 #' 
 #' @export
 #' 
-   ThrcTD <- function(T,D) {
+   ThrcTD <- function(Temp,D,digits=9) {
      y <- 0.
      icode <- 0
-     res <- .Fortran('ThrcTD', as.double(T), as.double(D), as.double(y), as.integer(icode))
-     options(digits=9)
+     res <- .Fortran('ThrcTD', as.double(Temp), as.double(D), as.double(y), as.integer(icode))
      if (res[[4]] != 0) { 
        error <-  as.character(errorCodes[which(errorCodes[,1]==res[[4]]),2])
        print(error)
      }
-     return(res[[3]])
+     return(round(res[[3]],digits=digits))
    }
 
 #' Isothermal Compressibility, Function of Temperature and Density
 #'
-#' @description The function \code{KapaTD(T,D)} returns the Isothermal Compressibility, Kapa, 
-#'     for given T [K] and D [kg m-3].
+#' @description The function \code{KapaTD(Temp,D,disgits=9)} returns the Isothermal Compressibility, Kapa, 
+#'     for given Temp [K] and D [kg m-3].
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
 #'     in accordance with the Revised Release on the IAPWS Formulation 1995 for the 
@@ -276,30 +275,30 @@
 #'     Water and Steam,  \url{http://www.iapws.org/relguide/IAPWS-95.html}. It is valid  
 #'     from the triple point to the pressure of 1000 MPa and temperature of 1273.
 #'     
-#' @param T Temperature [ K ]
+#' @param Temp Temperature [ K ]
 #' @param D Density [ kg m-3 ]
+#' @param digits Digits of results (optional)
 #' 
 #' @return The Isothermal Compressibility: Kapa [ MPa-1 ] and an Error
 #'      Message (if an error occur: \link{errorCodes})
 #' 
 #' @examples
-#' T <- 500.
+#' Temp <- 500.
 #' D <- 838.025
-#' Kapa <- KapaTD(T,D)
+#' Kapa <- KapaTD(Temp,D)
 #' Kapa
 #' 
 #' @export
 #' 
-KapaTD <- function(T,D) {
+KapaTD <- function(Temp,D,digits=9) {
   y <- 0.
   icode <- 0
-  res <- .Fortran('kapaTD', as.double(T), as.double(D), as.double(y), as.integer(icode))
-  options(digits=9)
+  res <- .Fortran('kapaTD', as.double(Temp), as.double(D), as.double(y), as.integer(icode))
   if (res[[4]] != 0) { 
     error <-  as.character(errorCodes[which(errorCodes[,1]==res[[4]]),2])
     print(error)
   }
-  return(res[[3]])
+  return(round(res[[3]],digits=digits))
 }
 
    
\ No newline at end of file
